import React, { useEffect } from 'react';
import Svg, { Defs, G, Path, Rect, LinearGradient, Stop } from 'react-native-svg';
import { useQRMatrix } from '../hooks/useQRMatrix';
import { useLogo } from '../hooks/useLogo';
import { Text } from 'react-native';
export const DEFAULT_TEST_ID = 'react-native-qrcode-composer';
export const QRCode = /*#__PURE__*/React.memo(({
  value = 'QR code message',
  size = 100,
  logo,
  logoStyle,
  style,
  getRef,
  onError,
  testID = DEFAULT_TEST_ID
}) => {
  const matrixResult = useQRMatrix({
    value,
    size,
    ...style
  });
  const {
    color = 'black',
    backgroundColor = 'white',
    quietZone = 0,
    linearGradient,
    gradientDirection = ['0%', '0%', '100%', '100%']
  } = style ?? {};
  const {
    logoComponent
  } = useLogo(size, `${testID}.logo`, logo, logoStyle);
  useEffect(() => {
    if (matrixResult.status === 'failure') {
      onError?.(matrixResult.error);
    }
  }, [matrixResult]);
  if (matrixResult.status === 'success') {
    const {
      path
    } = matrixResult.value;
    const actualSize = size + quietZone * 2;
    return /*#__PURE__*/React.createElement(Svg, {
      ref: getRef,
      viewBox: [-quietZone, -quietZone, actualSize, actualSize].join(' '),
      width: actualSize,
      height: actualSize,
      testID: `${testID}.qrcode`
    }, linearGradient !== undefined ? /*#__PURE__*/React.createElement(Defs, null, /*#__PURE__*/React.createElement(LinearGradient, {
      id: "grad",
      x1: gradientDirection[0],
      y1: gradientDirection[1],
      x2: gradientDirection[2],
      y2: gradientDirection[3]
    }, /*#__PURE__*/React.createElement(Stop, {
      offset: "0",
      stopColor: linearGradient[0],
      stopOpacity: "1"
    }), /*#__PURE__*/React.createElement(Stop, {
      offset: "1",
      stopColor: linearGradient[1],
      stopOpacity: "1"
    }))) : null, /*#__PURE__*/React.createElement(G, null, /*#__PURE__*/React.createElement(Rect, {
      x: -quietZone,
      y: -quietZone,
      width: actualSize,
      height: actualSize,
      fill: backgroundColor,
      rx: style?.cornerRadius,
      ry: style?.cornerRadius
    })), /*#__PURE__*/React.createElement(G, null, /*#__PURE__*/React.createElement(Path, {
      d: path,
      fill: linearGradient !== undefined ? 'url(#grad)' : color,
      fillRule: "evenodd",
      testID: `${testID}.path`
    })), logoComponent !== null && logoComponent);
  }
  return onError === undefined ? /*#__PURE__*/React.createElement(Text, {
    testID: `${testID}.error`
  }, matrixResult.error.message) : null;
});
//# sourceMappingURL=QRCode.js.map