import React, { useMemo } from 'react';
import { G, Defs, ClipPath, Rect, Image } from 'react-native-svg';
const isImageSourcePropType = logo => typeof logo === 'number' || typeof logo === 'object' && 'uri' in logo;
const isReactComponent = logo => typeof logo === 'function';
const logoBackgroundClipPath = 'logo-background-clip-path';
const logoClipPath = 'logo-clip-path';
export const useLogo = (qrCodeSize, testId, logo, logoStyle) => {
  const logoComponent = useMemo(() => {
    if (logo === undefined) {
      return null;
    }
    const {
      size = qrCodeSize * 0.2,
      backgroundColor = 'transparent',
      margin = 0,
      borderRadius = 0
    } = logoStyle ?? {};
    const marginOffset = margin * 2;
    const position = (qrCodeSize - size - marginOffset) / 2;
    const backgroundSize = size + marginOffset;
    const backgroundBorderRadius = borderRadius * (backgroundSize / 2);
    const LogoElement = isReactComponent(logo) ? logo : undefined;
    const logoImage = isImageSourcePropType(logo) ? logo : undefined;
    return /*#__PURE__*/React.createElement(G, {
      x: position,
      y: position,
      testID: testId
    }, /*#__PURE__*/React.createElement(Defs, null, /*#__PURE__*/React.createElement(ClipPath, {
      id: logoBackgroundClipPath
    }, /*#__PURE__*/React.createElement(Rect, {
      testID: `rect.${logoBackgroundClipPath}`,
      width: backgroundSize,
      height: backgroundSize,
      rx: backgroundBorderRadius,
      ry: backgroundBorderRadius
    })), /*#__PURE__*/React.createElement(ClipPath, {
      id: logoClipPath
    }, /*#__PURE__*/React.createElement(Rect, {
      testID: `rect.${logoClipPath}`,
      width: size,
      height: size,
      rx: borderRadius,
      ry: borderRadius
    }))), /*#__PURE__*/React.createElement(G, null, /*#__PURE__*/React.createElement(Rect, {
      testID: "rect.logo-background",
      width: backgroundSize,
      height: backgroundSize,
      fill: backgroundColor,
      clipPath: `url(#${logoBackgroundClipPath})`
    })), /*#__PURE__*/React.createElement(G, {
      x: margin,
      y: margin,
      testID: "g.logo-container"
    }, LogoElement !== undefined ? /*#__PURE__*/React.createElement(LogoElement, {
      width: size,
      height: size,
      clipPath: `url(#${logoClipPath})`
    }) : null, logoImage !== undefined ? /*#__PURE__*/React.createElement(Image, {
      width: size,
      height: size,
      href: logoImage,
      clipPath: `url(#${logoClipPath})`
    }) : null));
  }, [logo, logoStyle, qrCodeSize]);
  return {
    logoComponent
  };
};
//# sourceMappingURL=useLogo.js.map