export type QRCodeContents =
  | string
  | PlainText
  | URL
  | Email
  | Phone
  | SMS
  | WiFi
  | Geolocation
  | VCard
  | MECARD
  | CalendarEvent
  | Bitcoin
  | Twitter;

export const encodeQRCodeContents = (contents: QRCodeContents): string => {
  if (typeof contents === 'string') {
    return contents;
  }
  switch (contents.type) {
    case 'plain-text':
      return contents.content;
    case 'url':
      return contents.url;
    case 'email':
      return 'mailto:';
    case 'phone':
      return 'tel:';
    case 'sms':
      return 'sms:';
    case 'wifi':
      return 'WIFI:';
    case 'geolocation':
      return 'geo:';
    case 'vcard':
      return 'BEGIN:VCARD';
    case 'mecard':
      return 'MECARD:';
    case 'calendar-event':
      return 'BEGIN:VEVENT';
    case 'bitcoin':
      return 'bitcoin:';
    case 'twitter':
      return 'https://twitter.com/';
  }
};

interface PlainText {
  type: 'plain-text';
  content: string;
}

interface URL {
  type: 'url';
  url: string;
}

interface Email {
  type: 'email';
}

interface Phone {
  type: 'phone';
}

interface SMS {
  type: 'sms';
}

interface WiFi {
  type: 'wifi';
}

interface Geolocation {
  type: 'geolocation';
}

interface VCard {
  type: 'vcard';
}

interface MECARD {
  type: 'mecard';
}

interface CalendarEvent {
  type: 'calendar-event';
}

interface Bitcoin {
  type: 'bitcoin';
}

interface Twitter {
  type: 'twitter';
}
